@@ -24,6 +24,7 @@ struct Parameters {
     #[cfg_attr(not(feature = "spv-out"), allow(dead_code))]
     spv_version: (u8, u8),
     #[cfg_attr(not(feature = "spv-out"), allow(dead_code))]
+    #[serde(default)]
     spv_capabilities: naga::FastHashSet<spirv::Capability>,
     #[cfg_attr(not(feature = "spv-out"), allow(dead_code))]
     spv_debug: bool,
@@ -127,7 +128,11 @@ fn check_output_spv(
     let options = spv::Options {
         lang_version: params.spv_version,
         flags,
-        capabilities: Some(params.spv_capabilities.clone()),
+        capabilities: if params.spv_capabilities.is_empty() {
+            None
+        } else {
+            Some(params.spv_capabilities.clone())
+        },
     };
 
     let spv = spv::write_vec(module, info, &options).unwrap();
@@ -244,6 +249,8 @@ fn convert_wgsl() {
         ),
         ("access", Targets::SPIRV | Targets::METAL | Targets::WGSL),
         ("standard", Targets::SPIRV | Targets::METAL | Targets::GLSL),
+        //TODO: GLSL https://github.com/gfx-rs/naga/issues/874
+        ("interface", Targets::SPIRV | Targets::METAL),
     ];
 
     for &(name, targets) in inputs.iter() {
